# ApplicationStateSelector

The state for the application, either 'active' or 'disabled'. Setting to disabled will stop any components running in the agilicus infrastructure and disable access to the application. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **str** | The state for the application, either &#39;active&#39; or &#39;disabled&#39;. Setting to disabled will stop any components running in the agilicus infrastructure and disable access to the application.  | defaults to "active",  must be one of ["active", "disabled", ]
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


